[![Build Status](https://travis-ci.com/SwamyDev/gym-datums.svg?branch=master)](https://travis-ci.com/SwamyDev/gym-datums) [![Coverage Status](https://coveralls.io/repos/github/SwamyDev/gym-datums/badge.svg?branch=master)](https://coveralls.io/github/SwamyDev/gym-datums?branch=master)
# gym_datums
Gym environemnts that are converned with time series data such as asset portoflio management.
